import sys
import time 
from Phidget22.Devices.IR import *
from Phidget22.PhidgetException import *
from Phidget22.Phidget import *
from Phidget22.Net import *

try:
    ch = IR()
except RuntimeError as e:
    print("Runtime Exception %s" % e.details)
    print("Press Enter to Exit...\n")
    readin = sys.stdin.read(1)
    exit(1)

def IRAttached(self):
    try:
        attached = self
        print("\nAttach Event Detected (Information Below)")
        print("===========================================")
        print("Library Version: %s" % attached.getLibraryVersion())
        print("Serial Number: %d" % attached.getDeviceSerialNumber())
        print("Channel: %d" % attached.getChannel())
        print("Channel Class: %s" % attached.getChannelClass())
        print("Channel Name: %s" % attached.getChannelName())
        print("Device ID: %d" % attached.getDeviceID())
        print("Device Version: %d" % attached.getDeviceVersion())
        print("Device Name: %s" % attached.getDeviceName())
        print("Device Class: %d" % attached.getDeviceClass())
        print("\n")

    except PhidgetException as e:
        print("Phidget Exception %i: %s" % (e.code, e.details))
        print("Press Enter to Exit...\n")
        readin = sys.stdin.read(1)
        exit(1)   
    
def IRDetached(self):
    detached = self
    try:
        print("\nDetach event on Port %d Channel %d" % (detached.getHubPort(), detached.getChannel()))
    except PhidgetException as e:
        print("Phidget Exception %i: %s" % (e.code, e.details))
        print("Press Enter to Exit...\n")
        readin = sys.stdin.read(1)
        exit(1)   

def ErrorEvent(self, eCode, description):
    print("Error %i : %s" % (eCode, description))

def CodeHandler(self, code, bitCount, isRepeat):
    print("Code Read: 0x%s" % code)
    print("Bit Count: %d" % bitCount)
    print("Repeat: %d" % isRepeat)
    print("")

def LearnHandler(self, code, codeInfo):
    try:
        encodingStr = Encoding.getName(codeInfo.encoding)
        lengthStr = Length.getName(codeInfo.length)

        print("-----------------------------------------")
        print("Code: %s" % code)
        print("Bit Count: %d" % codeInfo.bitCount)
        print("Encoding: %s" % encodingStr)
        print("Length: %s" % lengthStr)
        print("Gap: %d" % codeInfo.gap)
        print("Trail: %d" % codeInfo.trail)
        print("Header: {%d, %d}" % (codeInfo.header[0], codeInfo.header[1]))
        print("One: {%d, %d}" % (codeInfo.one[0], codeInfo.one[1]))
        print("Zero: {%d, %d}" % (codeInfo.zero[0], codeInfo.zero[1]))
        print("Repeat: {"),
        for i  in range (0, 26):
            if(codeInfo.repeat[i] == 0):
                break;
            if(i == 0):
                print("%d" % codeInfo.repeat[i]),
            else:
                print(", %d" % codeInfo.repeat[i]),
        print("}")
        print("MinRepeat: %d" % codeInfo.minRepeat)
        print("Toggle Mask: %s" % codeInfo.toggleMask)
        print("Carrier Freq: %d" % codeInfo.carrierFrequency)
        print("Duty Cycle: %lf" % codeInfo.dutyCycle)
        print("-----------------------------------------")
        print(" ")
    except PhidgetException as e:
        print("Phidget Exception %i: %s" % (e.code, e.details))
        print("Press Enter to Exit...\n")
        readin = sys.stdin.read(1)
        exit(1)

try:
    ch.setOnAttachHandler(IRAttached)
    ch.setOnDetachHandler(IRDetached)
    ch.setOnErrorHandler(ErrorEvent)

    ch.setOnCodeHandler(CodeHandler)
    ch.setOnLearnHandler(LearnHandler)

    # Please review the Phidget22 channel matching documentation for details on the device
    # and class architecture of Phidget22, and how channels are matched to device features.

    # Specifies the serial number of the device to attach to.
    # For VINT devices, this is the hub serial number.
    #
    # The default is any device.
    #
    # ch.setDeviceSerialNumber(<YOUR DEVICE SERIAL NUMBER>) 

    # For VINT devices, this specifies the port the VINT device must be plugged into.
    #
    # The default is any port.
    #
    # ch.setHubPort(0)

    # Specifies which channel to attach to.  It is important that the channel of
    # the device is the same class as the channel that is being opened.
    #
    # The default is any channel.
    #
    # ch.setChannel(0)

    # In order to attach to a network Phidget, the program must connect to a Phidget22 Network Server.
    # In a normal environment this can be done automatically by enabling server discovery, which
    # will cause the client to discovery and connect to available servers.
    #
    # To force the channel to only match a network Phidget, set remote to 1.
    #
    # Net.enableServerDiscovery(PhidgetServerType.PHIDGETSERVER_DEVICEREMOTE)
    # ch.setIsRemote(1)

    print("Waiting for the Phidget IR Object to be attached...")
    ch.openWaitForAttachment(5000)
except PhidgetException as e:
    print("Phidget Exception %i: %s" % (e.code, e.details))
    print("Press Enter to Exit...\n")
    readin = sys.stdin.read(1)
    exit(1)

print("Gathering data for 10 seconds...")
time.sleep(10)

try:
    ch.close()
except PhidgetException as e:
    print("Phidget Exception %i: %s" % (e.code, e.details))
    print("Press Enter to Exit...\n")
    readin = sys.stdin.read(1)
    exit(1) 
print("Closed IR device")
exit(0)
                     
